@@ -17,8 +17,8 @@
 
    You should have received a copy of the GNU Library General Public
    License along with the Gnome Library; see the file COPYING.LIB.  If not,
-   write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
 
    Author: Colin Walters <walters@verbum.org>
 */
@@ -31,7 +31,6 @@
 #endif
 
 #include <gio/gio.h>
-#include <gdesktop-enums.h>
 
 G_BEGIN_DECLS
 
@@ -58,23 +57,10 @@ struct _GnomeWallClockClass
 	GObjectClass parent_class;
 };
 
-G_DEFINE_AUTOPTR_CLEANUP_FUNC(GnomeWallClock, g_object_unref)
-
 GType             gnome_wall_clock_get_type      (void);
 
-GnomeWallClock *  gnome_wall_clock_new           (void);
-
 const char *      gnome_wall_clock_get_clock     (GnomeWallClock *clock);
 
-GTimeZone *       gnome_wall_clock_get_timezone  (GnomeWallClock *clock);
-
-char *            gnome_wall_clock_string_for_datetime (GnomeWallClock      *self,
-							GDateTime           *now,
-							GDesktopClockFormat  clock_format,
-							gboolean             show_weekday,
-							gboolean             show_full_date,
-							gboolean             show_seconds);
-
 G_END_DECLS
 
 #endif
